| Title: | A method for inferring microbial networks with false discovery rate control for clustered and unclustered samples |
|---|---|
| Description: | TestNet is a testing method for inferring microbial networks. It differs from existing microbial network analyses in that it provides calibrated results by controlling the false discovery rate. TestNet accounts for the features of compositionality, sparsity, and overdispersion in taxa count data. It also accommodates both independent and clustered samples, offers separate linear and nonlinear tests for each pair of taxa, and includes an omnibus test that bypasses the need to pre-specify the type of relationship for each pair of taxa. |
| Authors: | Yi-Juan Hu [aut, cre] |
| Maintainer: | Yi-Juan Hu <[email protected]> |
| License: | GPL (>=2) |
| Version: | 1.0 |
| Built: | 2026-06-03 13:41:26 UTC |
| Source: | https://github.com/yijuanhu/testnet |
This table contains read count data simulated for 100 samples and 46 OTUs and under the AR1 dependence structure
data("sim.otu.tab")data("sim.otu.tab")
A data frame with 100 observations on 46 OTUs
data(sim.otu.tab)data(sim.otu.tab)
This function generates a p-value and a q-value for each (linear, nonlinear, or omnibus) test of a pair of taxa.
TestNet( otu.tab, clustered.data = FALSE, cluster.id = NULL, fdr.nominal = 0.1, n.perm.max = NULL, seed = 123 )TestNet( otu.tab, clustered.data = FALSE, cluster.id = NULL, fdr.nominal = 0.1, n.perm.max = NULL, seed = 123 )
otu.tab |
An |
clustered.data |
A logical variable indicating whether the samples are clustered. The default is FALSE. |
cluster.id |
An array of |
fdr.nominal |
The nominal FDR level. The default is 0.1. |
n.perm.max |
The maximum number of permutation replicates. The default is NULL, in which case a maximum of |
seed |
a single-value integer seed for the random process of drawing permutation replicates. The default is 123. |
a list consisting of
p.linear |
An |
q.linear |
An |
p.nonlinear |
An |
q.nonlinear |
An |
p.omni |
An |
q.omni |
An |
which.pmin |
An |
Yi-Juan Hu <[email protected]>
Su C, Mao Y, He M, Van Doren VE, Kelley CF, Hu YJ (2026). TestNet: a method for inferring microbial networks with false discovery rate control for clustered and unclustered samples. Genome Biology, in press.
data(sim.otu.tab) TestNet.res <- TestNet(otu.tab = sim.otu.tab)data(sim.otu.tab) TestNet.res <- TestNet(otu.tab = sim.otu.tab)